@@ -346,31 +346,31 @@ class TestRunProcess(BasedirMixin, unittest.TestCase):
 
         self.assertTrue({'rc': 0} in b.updates, b.show())
 
-    @compat.usesFlushLoggedErrors
+    @defer.inlineCallbacks
     def test_startCommand_exception(self):
         b = FakeWorkerForBuilder(self.basedir)
         s = runprocess.RunProcess(b, ['whatever'], self.basedir)
 
         # set up to cause an exception in _startCommand
         def _startCommand(*args, **kwargs):
-            raise RuntimeError()
+            raise RuntimeError('error message')
         s._startCommand = _startCommand
 
-        d = s.start()
+        try:
+            yield s.start()
+        except AbandonChain:
+            pass
 
-        def check(err):
-            err.trap(AbandonChain)
-            stderr = []
-            # Here we're checking that the exception starting up the command
-            # actually gets propagated back to the master in stderr.
-            for u in b.updates:
-                if 'stderr' in u:
-                    stderr.append(u['stderr'])
-            stderr = "".join(stderr)
-            self.assertTrue("RuntimeError" in stderr, stderr)
-        d.addBoth(check)
-        d.addBoth(lambda _: self.flushLoggedErrors())
-        return d
+        stderr = []
+        # Here we're checking that the exception starting up the command
+        # actually gets propagated back to the master in stderr.
+        for u in b.updates:
+            if 'stderr' in u:
+                stderr.append(u['stderr'])
+        stderr = ''.join(stderr)
+        self.assertTrue(stderr.startswith('error in RunProcess._startCommand (error message)'))
+
+        yield self.flushLoggedErrors()
 
     @defer.inlineCallbacks
     def testLogEnviron(self):
